==> GANN-Beta-1.5.tar.gz: GANN/src/gann.cpp <==
/* 
   
   Geeks Artificial Neural Network (G.A.N.N) - Main File
   
   Copyright GNU/GPL 2005-2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



//Include Global Declarations
#include "headers/gglobdec.h"

//Main Function
int main(int argc,char **argv)

{

    //Variables
    int i;			//A Counter
    
    //Graphical Menu
    printf("-------------------------\n");
    printf("******   G.A.N.N   ******\n");
    printf("-------------------------\n");
    printf("=========================\n");
    printf("George Delaportas\n");
    printf("Dimitris Vlachos\n");
    printf("Copyright GNU/GPL 2006\n");
    printf("=========================\n\n");
    printf("Please Select An Option\n");
    printf("1.Create A G.A.N.N And Teach It\n");
    printf("2.Run An Existing G.A.N.N From GKDB\n");
    printf("3.Create A G.A.N.N - Teach It And Run It\n");
    printf("4.Remove Registrations From GKDB\n");
    printf("5.Exit\n");
    printf("Choice:");
    
    scanf("%i",&i);
    
    printf("\n");
    
    //Check Choices
    if (i==1)
    
    {
    
        //Create New G.A.N.N
        GSNMC();
        
        printf("Restoring Data...\n");
        
        //Load GIOD And GMap Data
        GDMLoader();
        
        printf("Done!\n\n");
        
        //Simulate G.A.N.N At Learning Mode
        GNMS(0);
    
    }
    
    else if (i==2)
    
    {
    
        //Simulate G.A.N.N At Running Mode
        GNMS(1);
    
    }
    
    else if (i==3)
    
    {
    
        //Create New G.A.N.N
        GSNMC();
        
        printf("Restoring Data...\n");
        
        //Load GIOD And GMap Data
        GDMLoader();
        
        printf("Done!\n\n");
        
        //Simulate G.A.N.N At Learning Mode
        GNMS(0);
        
        //Simulate G.A.N.N At Running Mode
        GNMS(1);
    
    }
    
    else if (i==4)
    
    {
    
        printf("Please Specify The Registration You Want To Remove\n");
        printf("(Registration Number Must Be Between 1-%i)\n",MAX_REG);
        printf("Choice:");
        
        scanf("%i",&i);
        
        if (i<1 OR i>MAX_REG)
        
        {
        
            printf("Error: Wrong Registration Number!\n");
            
            exit(1);
        
        }
        
        GRemData(i);
        
        printf("Done!\n");
    
    }
    
    else if (i==5)
    
    {
    
        printf("Thank You For Using G.A.N.N\n");
        printf("Goodbye!\n");
        
        exit(0);
    
    }
    
    else
    
    {
    
        printf("Error: Wrong Choice Specified!\n");
        
        exit(1);
    
    }
    
    exit(0);

}

/* ------------------------------------------------------------------------ */

==> GANN-Beta-1.6.tar.gz: GANN/src/gann.cpp <==
/* 
   
   Geeks Artificial Neural Network (G.A.N.N) - Main File
   
   Copyright GNU/GPL 2005-2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



//Include Global Declarations
#include "headers/gglobdec.h"

//Main Function
int main(int argc,char **argv)

{

    //Variables
    int i;			//A Counter
    
    //Graphical Menu
    printf("-------------------------\n");
    printf("******   G.A.N.N   ******\n");
    printf("-------------------------\n");
    printf("=========================\n");
    printf("George Delaportas\n");
    printf("Dimitris Vlachos\n");
    printf("Copyright GNU/GPL 2006\n");
    printf("=========================\n\n");
    printf("Please Select An Option\n");
    printf("1.Create A G.A.N.N And Teach It\n");
    printf("2.Run An Existing G.A.N.N From GKDB\n");
    printf("3.Create A G.A.N.N - Teach It And Run It\n");
    printf("4.Remove Registrations From GKDB\n");
    printf("5.Exit\n");
    printf("Choice:");
    
    scanf("%i",&i);
    
    printf("\n");
    
    //Check Choices
    if (i==1)
    
    {
    
        //Create New G.A.N.N
        GSNMC();
        
        printf("Loading Data...\n");
        
        //Load GIOD And GMap Data
        GDMLoader();
        
        printf("Done!\n\n");
        
        //Simulate G.A.N.N At Learning Mode
        GNMS(0);
    
    }
    
    else if (i==2)
    
    {
    
        //Simulate G.A.N.N At Running Mode
        GNMS(1);
    
    }
    
    else if (i==3)
    
    {
    
        //Create New G.A.N.N
        GSNMC();
        
        printf("Loading Data...\n");
        
        //Load GIOD And GMap Data
        GDMLoader();
        
        printf("Done!\n\n");
        
        //Simulate G.A.N.N At Learning Mode
        GNMS(0);
        
        //Simulate G.A.N.N At Running Mode
        GNMS(1);
    
    }
    
    else if (i==4)
    
    {
    
        printf("Please Specify The Registration You Want To Remove\n");
        printf("(Registration Number Must Be Between 1-%i)\n",MAX_REG);
        printf("Choice:");
        
        scanf("%i",&i);
        
        if (i<1 OR i>MAX_REG)
        
        {
        
            printf("Error:Wrong Registration Number!\n");
            
            exit(1);
        
        }
        
        GRemData(i);
        
        printf("Done!\n");
    
    }
    
    else if (i==5)
    
    {
    
        printf("Thank You For Using G.A.N.N\n");
        printf("Goodbye!\n");
        
        exit(0);
    
    }
    
    else
    
    {
    
        printf("Error:Wrong Choice Specified!\n");
        
        exit(1);
    
    }
    
    exit(0);

}

/* ------------------------------------------------------------------------ */
